# coding: utf-8

"""
    Coin CRDB Rest API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 3.0.0
    Contact: devops@coin.nl
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PortingRequestAnswerDelayed(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dossierid': 'str',
        'donornetworkoperator': 'str',
        'donorserviceprovider': 'str',
        'answerduedatetime': 'str',
        'reasoncode': 'str'
    }

    attribute_map = {
        'dossierid': 'dossierid',
        'donornetworkoperator': 'donornetworkoperator',
        'donorserviceprovider': 'donorserviceprovider',
        'answerduedatetime': 'answerduedatetime',
        'reasoncode': 'reasoncode'
    }

    def __init__(self, dossierid=None, donornetworkoperator=None, donorserviceprovider=None, answerduedatetime=None, reasoncode=None):  # noqa: E501
        """PortingRequestAnswerDelayed - a model defined in Swagger"""  # noqa: E501

        self._dossierid = None
        self._donornetworkoperator = None
        self._donorserviceprovider = None
        self._answerduedatetime = None
        self._reasoncode = None
        self.discriminator = None

        self.dossierid = dossierid
        self.donornetworkoperator = donornetworkoperator
        if donorserviceprovider is not None:
            self.donorserviceprovider = donorserviceprovider
        if answerduedatetime is not None:
            self.answerduedatetime = answerduedatetime
        if reasoncode is not None:
            self.reasoncode = reasoncode

    @property
    def dossierid(self):
        """Gets the dossierid of this PortingRequestAnswerDelayed.  # noqa: E501


        :return: The dossierid of this PortingRequestAnswerDelayed.  # noqa: E501
        :rtype: str
        """
        return self._dossierid

    @dossierid.setter
    def dossierid(self, dossierid):
        """Sets the dossierid of this PortingRequestAnswerDelayed.


        :param dossierid: The dossierid of this PortingRequestAnswerDelayed.  # noqa: E501
        :type: str
        """
        if dossierid is None:
            raise ValueError("Invalid value for `dossierid`, must not be `None`")  # noqa: E501
        if dossierid is not None and not re.search(r'[-0-9A-Z]{5,26}', dossierid):  # noqa: E501
            raise ValueError(r"Invalid value for `dossierid`, must be a follow pattern or equal to `/[-0-9A-Z]{5,26}/`")  # noqa: E501

        self._dossierid = dossierid

    @property
    def donornetworkoperator(self):
        """Gets the donornetworkoperator of this PortingRequestAnswerDelayed.  # noqa: E501


        :return: The donornetworkoperator of this PortingRequestAnswerDelayed.  # noqa: E501
        :rtype: str
        """
        return self._donornetworkoperator

    @donornetworkoperator.setter
    def donornetworkoperator(self, donornetworkoperator):
        """Sets the donornetworkoperator of this PortingRequestAnswerDelayed.


        :param donornetworkoperator: The donornetworkoperator of this PortingRequestAnswerDelayed.  # noqa: E501
        :type: str
        """
        if donornetworkoperator is None:
            raise ValueError("Invalid value for `donornetworkoperator`, must not be `None`")  # noqa: E501
        if donornetworkoperator is not None and not re.search(r'[0-9A-Z]{3,6}', donornetworkoperator):  # noqa: E501
            raise ValueError(r"Invalid value for `donornetworkoperator`, must be a follow pattern or equal to `/[0-9A-Z]{3,6}/`")  # noqa: E501

        self._donornetworkoperator = donornetworkoperator

    @property
    def donorserviceprovider(self):
        """Gets the donorserviceprovider of this PortingRequestAnswerDelayed.  # noqa: E501


        :return: The donorserviceprovider of this PortingRequestAnswerDelayed.  # noqa: E501
        :rtype: str
        """
        return self._donorserviceprovider

    @donorserviceprovider.setter
    def donorserviceprovider(self, donorserviceprovider):
        """Sets the donorserviceprovider of this PortingRequestAnswerDelayed.


        :param donorserviceprovider: The donorserviceprovider of this PortingRequestAnswerDelayed.  # noqa: E501
        :type: str
        """
        if donorserviceprovider is not None and not re.search(r'[0-9A-Z]{3,6}', donorserviceprovider):  # noqa: E501
            raise ValueError(r"Invalid value for `donorserviceprovider`, must be a follow pattern or equal to `/[0-9A-Z]{3,6}/`")  # noqa: E501

        self._donorserviceprovider = donorserviceprovider

    @property
    def answerduedatetime(self):
        """Gets the answerduedatetime of this PortingRequestAnswerDelayed.  # noqa: E501


        :return: The answerduedatetime of this PortingRequestAnswerDelayed.  # noqa: E501
        :rtype: str
        """
        return self._answerduedatetime

    @answerduedatetime.setter
    def answerduedatetime(self, answerduedatetime):
        """Sets the answerduedatetime of this PortingRequestAnswerDelayed.


        :param answerduedatetime: The answerduedatetime of this PortingRequestAnswerDelayed.  # noqa: E501
        :type: str
        """
        if answerduedatetime is not None and not re.search(r'[0-9]{14}', answerduedatetime):  # noqa: E501
            raise ValueError(r"Invalid value for `answerduedatetime`, must be a follow pattern or equal to `/[0-9]{14}/`")  # noqa: E501

        self._answerduedatetime = answerduedatetime

    @property
    def reasoncode(self):
        """Gets the reasoncode of this PortingRequestAnswerDelayed.  # noqa: E501


        :return: The reasoncode of this PortingRequestAnswerDelayed.  # noqa: E501
        :rtype: str
        """
        return self._reasoncode

    @reasoncode.setter
    def reasoncode(self, reasoncode):
        """Sets the reasoncode of this PortingRequestAnswerDelayed.


        :param reasoncode: The reasoncode of this PortingRequestAnswerDelayed.  # noqa: E501
        :type: str
        """
        if reasoncode is not None and not re.search(r'[1-9][0-9]{0,4}', reasoncode):  # noqa: E501
            raise ValueError(r"Invalid value for `reasoncode`, must be a follow pattern or equal to `/[1-9][0-9]{0,4}/`")  # noqa: E501

        self._reasoncode = reasoncode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PortingRequestAnswerDelayed, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PortingRequestAnswerDelayed):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
